﻿using FlowerShopDataModels;
using FlowerShopContracts.BindingModels;
using FlowerShopContracts.ViewModels;
using System.ComponentModel.DataAnnotations.Schema;
using System.ComponentModel.DataAnnotations;

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using FlowerShopDataModels.Enums;

namespace FlowerShopDatabaseImplement.Models
{
    public class Order : IOrderModel
    {
        public int Id { get; private set; }
        [Required]
        public int Count { get; private set; }
        [Required]
        public double Sum { get; private set; }
        [Required]
        public OrderStatus Status { get; private set; }
        [Required]
        public DateTime DateCreate { get; private set; }
        public DateTime? DateImplement { get; private set; }
        [Required]
        public int FlowerId { get; private set; }
        [Required]
        public int ClientId { get; private set; }
        public virtual Client? Client { get; private set; }
        public virtual Flower? Flower { get; set; }
		public int? ImplementerId { get; private set; } = null;
		public virtual Implementer? Implementer { get; private set; }
		public static Order? Create(OrderBindingModel model)
        {
            if (model == null)
            {
                return null;
            }
            return new Order()
            {
                Id = model.Id,
                Count = model.Count,
                Sum = model.Sum,
                Status = model.Status,
                DateCreate = model.DateCreate,
                DateImplement = model.DateImplement,
                FlowerId = model.FlowerId,
                ClientId = model.ClientId,
				ImplementerId = model.ImplementerId,
			};
        }

        public void Update(OrderBindingModel? model)
        {
            if (model == null)
            {
                return;
            }
            Status = model.Status;
            DateImplement = model.DateImplement;
			ImplementerId = model.ImplementerId;
		}

        public OrderViewModel GetViewModel => new()
        {
            FlowerId = FlowerId,
            Count = Count,
            Sum = Sum,
            Status = Status,
            ClientId = ClientId,
			ImplementerId = ImplementerId,
			DateCreate = DateCreate,
            DateImplement = DateImplement,
            FlowerName = Flower?.FlowerName ?? String.Empty ,
            Id = Id,
            ClientFIO = Client?.ClientFIO ?? String.Empty,
			ImplementerFIO = (Implementer != null ? Implementer.ImplementerFIO : string.Empty)
		};

    }
}
